@@ -5,7 +5,7 @@ define(["dojo/_base/lang", "../_base", "dojo/_base/config", "dojo/aspect"
 
 		// summary:
 		//		plugin to have analyitcs return the base info dojo collects
-		this.addData = lang.hitch(dxa, "addData", "consoleMessages");
+		consoleMessages.addData = lang.hitch(dxa, "addData", "consoleMessages");
 
 		var lvls = config["consoleLogFuncs"] || ["error", "warn", "info", "rlog"];
 		if(!console){
@@ -13,7 +13,7 @@ define(["dojo/_base/lang", "../_base", "dojo/_base/config", "dojo/aspect"
 		}
 
 		for(var i = 0; i < lvls.length; i++){
-			var fnName = lvls[i], _addData = lang.hitch(this, "addData", fnName);
+			var fnName = lvls[i], _addData = lang.hitch(consoleMessages, "addData", fnName);
 			if(console[fnName]){
 				aspect.after(console, fnName, _addData,true);
 			}else{
